==> nextcloud-19.0.3.tgz: nextcloud/apps/theming/l10n/cs.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítání náhledu…",
    "Saved" : "Uloženo",
    "Admin" : "Správa",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "Name cannot be empty" : "Je třeba zadat název",
    "The given name is too long" : "Zadaný název je příliš dlouhý",
    "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
    "The given web address is not a valid URL" : "Zadaná webová adresa není platná URL",
    "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platnou URL adresou",
    "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platná URL adresa",
    "The given slogan is too long" : "Zadaný slogan je příliš dlouhý",
    "The given color is invalid" : "Zadaná barva není platná",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, která byla zadána ve HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "No file uploaded" : "Nenahrán žádný soubor",
    "Unsupported image type" : "Nepodporovaný typ obrázku",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
    "Theming" : "Motiv vzhledu",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
    "Open documentation" : "Otevřít dokumentaci",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
    "Name" : "Název",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Web link" : "Webový odkaz",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Barva",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrát nové logo",
    "Login image" : "Přihlašovací obrázek",
    "Upload new login background" : "Nahrát nové přihlašovací pozadí",
    "Remove background image" : "Odebrat obrázek pozadí",
    "Advanced options" : "Pokročilé předvolby",
    "Legal notice link" : "Odkaz na právní upozornění",
    "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
    "Header logo" : "Logo v záhlaví",
    "Upload new header logo" : "Nahrát nové logo do záhlaví",
    "Favicon" : "ikona webu",
    "Upload new favicon" : "Nahrát novou ikonu webu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-19.0.4.tgz: nextcloud/apps/theming/l10n/cs.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítání náhledu…",
    "Saved" : "Uloženo",
    "Admin" : "Správa",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "Name cannot be empty" : "Je třeba zadat název",
    "The given name is too long" : "Zadaný název je příliš dlouhý",
    "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
    "The given web address is not a valid URL" : "Zadaná webová adresa není platná URL",
    "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platnou URL adresou",
    "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platná URL adresa",
    "The given slogan is too long" : "Zadaný slogan je příliš dlouhý",
    "The given color is invalid" : "Zadaná barva není platná",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, která byla zadána ve HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "No file uploaded" : "Nenahrán žádný soubor",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
    "Theming" : "Motiv vzhledu",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
    "Open documentation" : "Otevřít dokumentaci",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
    "Name" : "Název",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Web link" : "Webový odkaz",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Barva",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrát nové logo",
    "Login image" : "Přihlašovací obrázek",
    "Upload new login background" : "Nahrát nové přihlašovací pozadí",
    "Remove background image" : "Odebrat obrázek pozadí",
    "Advanced options" : "Pokročilé předvolby",
    "Legal notice link" : "Odkaz na právní upozornění",
    "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
    "Header logo" : "Logo v záhlaví",
    "Upload new header logo" : "Nahrát nové logo do záhlaví",
    "Favicon" : "ikona webu",
    "Upload new favicon" : "Nahrát novou ikonu webu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy.",
    "Unsupported image type" : "Nepodporovaný typ obrázku"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
